==> liquidwar-5.3.0.tar.gz: liquidwar-5.3.0/src/ticker.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/********************************************************************/
/* this software is protected by the GPL, see copying.txt           */
/********************************************************************/

/********************************************************************/
/* nom           : ticker.c                                         */
/* contenu       : gestion d'un compteur de milliemes de seconde    */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <allegro.h>

#include "ticker.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

static int TICKER_VALUE=0;

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/


/*------------------------------------------------------------------*/
/* mise en place du chrono                                          */
/*------------------------------------------------------------------*/

/*------------------------------------------------------------------*/
static void ticker_handler (void)
{
 TICKER_VALUE++;
}
END_OF_FUNCTION (ticker_handler);

/*------------------------------------------------------------------*/
int start_ticker (void)
{
 int result=0;
 #ifdef ALLEGRO_DOS
 LOCK_FUNCTION (ticker_handler);
 LOCK_VARIABLE (TICKER_VALUE);
 
 result=install_int_ex (ticker_handler, MSEC_TO_TIMER (1));
 #endif
 return result;
}

/*------------------------------------------------------------------*/
void stop_ticker (void)
{
 #ifdef ALLEGRO_DOS
 remove_int (ticker_handler);
 #endif
}

/*------------------------------------------------------------------*/
int get_ticker (void)
{
  #ifdef ALLEGRO_DOS
  return TICKER_VALUE;
  #else
  return ++TICKER_VALUE;
  #endif
}

==> liquidwar-5.4.2.tar.gz: liquidwar-5.4.2/src/ticker.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/********************************************************************/
/* this software is protected by the GPL, see copying.txt           */
/********************************************************************/

/********************************************************************/
/* nom           : ticker.c                                         */
/* contenu       : gestion d'un compteur de milliemes de seconde    */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <allegro.h>

#include "ticker.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

#ifdef ALLEGRO_DOS
    #define TICKER_STEP 5
#else
    #define TICKER_STEP 10
#endif
static int TICKER_VALUE=0;

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/


/*------------------------------------------------------------------*/
/* mise en place du chrono                                          */
/*------------------------------------------------------------------*/

/*------------------------------------------------------------------*/
static void ticker_handler (void)
{
 TICKER_VALUE+=TICKER_STEP;
}
END_OF_FUNCTION (ticker_handler);

/*------------------------------------------------------------------*/
int start_ticker (void)
{
 int result=0;
 //#ifdef ALLEGRO_DOS
 LOCK_FUNCTION (ticker_handler);
 LOCK_VARIABLE (TICKER_VALUE);
 
 result=install_int_ex (ticker_handler, MSEC_TO_TIMER (TICKER_STEP));
 //#endif
 return result;
}

/*------------------------------------------------------------------*/
void stop_ticker (void)
{
 //#ifdef ALLEGRO_DOS
 remove_int (ticker_handler);
 //#endif
}

/*------------------------------------------------------------------*/
int get_ticker (void)
{
  //#ifdef ALLEGRO_DOS
  return TICKER_VALUE;
  //#else
  //return ++TICKER_VALUE;
  //#endif
}
